# 表管理知识库

## 核心功能
单表数据管理，支持全量和增量更新模式。

## Table类

### 初始化参数
- `fn`: 数据获取函数
- `tb`: 表名
- `update_time`: 更新时间
- `mode`: 表访问模式（F-全量，I-增量）

### 执行流程

#### 初始化
1. 存储输入参数
2. 计算数据存储目录路径
3. 初始化日志记录器
4. 设置详细模式

#### update方法
更新最新数据。

**执行流程**:
1. 检查是否需要更新
2. 如果需要，调用_do_job方法

#### _need_update方法
判断是否需要更新数据。

**执行流程**:
1. 检查存储目录是否存在
2. 如果不存在，创建目录并返回True
3. 如果存在，获取最新文件的修改时间
4. 比较修改时间与最新交易日
5. 根据更新时间和当前时间决定是否需要更新
6. 返回布尔值结果

#### _do_job方法
执行数据获取和存储。

**执行流程**:
1. 调用数据获取函数
2. 检查返回数据是否为空
3. 根据模式选择存储策略
   - F模式：覆盖存储为0.parquet
   - I模式：增量存储为UUID.parquet
4. 存储数据文件

#### get_value方法
获取数据。

**执行流程**:
1. 检查是否需要更新
2. 调用scan函数惰性加载数据
3. 根据eager参数决定返回DataFrame或LazyFrame

## 表访问模式

### TableMode枚举
- `F` (full): 全量更新，覆盖旧数据
- `I` (increment): �量更新，保留历史数据

## 自动版本管理
通过文件名和修改时间自动管理数据版本，支持历史数据追溯。